@@ -638,8 +638,8 @@ Program ini didasarkan pada ObConf yang dikembangkan oleh para pengembang beriku
     <name>QObject</name>
     <message>
         <location filename="../archive.cpp" line="26"/>
-        <source>&quot;%1&quot; was installed to %1</source>
-        <translation>&quot;%1&quot; telah dipasang ke %1</translation>
+        <source>&quot;%1&quot; was installed to %2</source>
+        <translation type="unfinished">&quot;%2&quot; telah dipasang ke %2 {1&quot;?}</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
